# RSvIDX

## Vector indexing system

### Vector indexing

**RSvIDX can be used for general purpose vector indexing and similarity search. Applications include:**

- Semantic search
- Document deduplication
- Recommendation
- Classification
- Image search
- Reverse image search
- Audio similarity (like Shazam)
- Q&A


### Features
- fast and efficient math library
- optimised persistant operations (you now no longer need to explicitly save the index as this is scheduled automatically)
- better in-memory performance compaired to RSvIDX_v3
- no dependencies (new build size is 98% smaller)
- Usable in C with bindings in Python3
- No intermideate C bindings


### Example:

Try out https://apps.apple.com/gb/app/headlines-today/id1363257410 on the App Store for a semantic search example.
